/*  Copyright 2008 Theo Berkau

    This file is part of Yabause.

    Yabause is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Yabause is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Yabause; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
*/

#ifndef DISASM_H
#define DISASM_H

#include "custctl.h"

#define DISASM TEXT("YabauseDisassembler")
#define DIS_SETDISFUNC          WM_USER+11
#define DIS_SETENDADDRESS       WM_USER+12
#define DIS_GOTOADDRESS         WM_USER+13
#define DIS_SETPC               WM_USER+14
#define DIS_GETCURSEL           WM_USER+15
#define DIS_GETCURADDRESS       WM_USER+16

void InitDisasm();

#endif
